# lifeactuary_1.2
Package *lifeactuary* is a Python library to perform actuarial mathematics on life contingencies and classical financial mathematics computations. Versatile, simple and easy to use. The main functions are implemented using the usual actuarial approach, making it a natural choice for the life actuary.
This document is produced as a descriptive tool on how to use the package and as a user guide for the developed actuarial functions. For each actuarial function, an illustrative example is provided. 
        
The package uses Python version >= 3.6.

This package and functions herein are provided as is, without any guarantee regarding the accuracy of calculations. It's distributed using the [MIT License](https://en.wikipedia.org/wiki/MIT_License) and the authors disclaim any liability arising by any losses due to direct or indirect use of this package.
    
This package is still under development and further useful and interesting functions will be available any time soon.

You should also visit for version 1.0, [lifeactuary at github](https://github.com/parcr/lifeactuary) to download the folder *"soa_tables"* containing a set of tables, namely the ones used in the examples in the manual.

For version 1.2, take a look for  [lifeactuary_1.2 at github](https://github.com/parcr/lifeactuary_1.2) to download the folder *"soa_tables"* containing a set of tables, namely the ones used in the examples in the manual.
